exceptiontools.ContiguityError
==============================

.. abjad-lineage:: abjad.tools.exceptiontools.ContiguityError.ContiguityError

.. autoclass:: abjad.tools.exceptiontools.ContiguityError.ContiguityError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.ContiguityError.ContiguityError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ContiguityError.ContiguityError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ContiguityError.ContiguityError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ContiguityError.ContiguityError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ContiguityError.ContiguityError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ContiguityError.ContiguityError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ContiguityError.ContiguityError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ContiguityError.ContiguityError.__unicode__
   :noindex:
